<?php

namespace Litecms\Addons\Providers;

use Illuminate\Support\ServiceProvider;

class AddonsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'addons');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'addons');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.addons', function ($app) {
            return $this->app->make('Litecms\Addons\Addons');
        });

                // Bind Addons to repository
        $this->app->bind(
            'Litecms\Addons\Interfaces\AddonsRepositoryInterface',
            \Litecms\Addons\Repositories\Eloquent\AddonsRepository::class
        );

        $this->app->register(\Litecms\Addons\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Addons\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.addons'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/addons.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/addons')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/addons')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
